@@ -25,12 +25,12 @@ from .util import find_program, backtick
 
 
 # internal MIME database
-mimedb = None
+mimedb: mimetypes.MimeTypes | None = None
 
 
 def init_mimedb() -> None:
     """Initialize the internal MIME database."""
-    global mimedb
+    global mimedb  # noqa PLW0603
     try:
         mimedb = mimetypes.MimeTypes(strict=False)
     except Exception as msg:
@@ -113,7 +113,7 @@ def guess_mime(filename: str) -> tuple[str | None, str | None]:
         mime, encoding = guess_mime_mimedb(filename)
     else:
         # check if file extension detection differs.
-        mime2, encoding2 = guess_mime_mimedb(filename)
+        mime2, _encoding2 = guess_mime_mimedb(filename)
         if mime2 != mime:
             log_info(
                 f"Different MIME types detected for {filename}: "
@@ -151,7 +151,7 @@ def guess_mime_mimedb(filename: str) -> tuple[str | None, str | None]:
     mime, encoding = None, None
     if mimedb is not None:
         mime, encoding = mimedb.guess_type(filename, strict=False)
-    if mime is None and encoding is None:
+    if mimedb is not None and mime is None and encoding is None:
         # try with lowercase extension, since we configure our mimedb entries only with lowercase
         # this way, files like "t.GZ" are recognized
         root, ext = os.path.splitext(filename)
