@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # Copyright (C) 2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
@@ -14,8 +13,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the lz4 program."""
-from . import (extract_singlefile_standard, create_singlefile_standard,
-    test_singlefile_standard)
+
+from . import (
+    extract_singlefile_standard,
+    create_singlefile_standard,
+    test_singlefile_standard,
+)
 
 extract_lz4 = extract_singlefile_standard
 create_lz4 = create_singlefile_standard
