@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2011-2012 Bastian Kleineidam
+# Copyright (C) 2011-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,8 +13,12 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the clzip program."""
-from . import extract_singlefile_standard, \
-    test_singlefile_standard, create_singlefile_standard
+
+from . import (
+    extract_singlefile_standard,
+    test_singlefile_standard,
+    create_singlefile_standard,
+)
 
 
 extract_lzip = extract_singlefile_standard
