@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -14,20 +13,33 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """Archive commands for the rpm2cpio program."""
+
 import os
 from .. import util
 
-def extract_rpm (archive, compression, cmd, verbosity, interactive, outdir):
+
+def extract_rpm(archive, compression, cmd, verbosity, interactive, outdir):
     """Extract a RPM archive."""
     # also check cpio
     cpio = util.find_program("cpio")
     if not cpio:
-        raise util.PatoolError("cpio(1) is required for rpm2cpio extraction; please install it")
+        raise util.PatoolError(
+            "cpio(1) is required for rpm2cpio extraction; please install it"
+        )
     path = util.shell_quote(os.path.abspath(archive))
-    cmdlist = [util.shell_quote(cmd), path, "|", util.shell_quote(cpio),
-        '--extract', '--make-directories', '--preserve-modification-time',
-        '--no-absolute-filenames', '--force-local', '--nonmatching',
-        r'"*\.\.*"']
+    cmdlist = [
+        util.shell_quote(cmd),
+        path,
+        "|",
+        util.shell_quote(cpio),
+        '--extract',
+        '--make-directories',
+        '--preserve-modification-time',
+        '--no-absolute-filenames',
+        '--force-local',
+        '--nonmatching',
+        r'"*\.\.*"',
+    ]
     if verbosity > 1:
         cmdlist.append('-v')
     return (cmdlist, {'cwd': outdir, 'shell': True})
