@@ -28,8 +28,6 @@ from .log import log_info
 class PatoolError(Exception):
     """Raised when errors occur."""
 
-    pass
-
 
 def backtick(cmd: Sequence[str], encoding: str = 'utf-8') -> str:
     """Return decoded output from command."""
@@ -47,7 +45,9 @@ def run_under_pythonw() -> bool:
     )
 
 
-def run(cmd: Sequence[str], verbosity: int = 0, **kwargs) -> int:
+def run(
+    cmd: Sequence[str], verbosity: int = 0, interactive: bool = True, **kwargs
+) -> int:
     """Run command without error checking.
     @return: command return code
     """
@@ -61,8 +61,9 @@ def run(cmd: Sequence[str], verbosity: int = 0, **kwargs) -> int:
         kwargs["creationflags"] = (
             subprocess.CREATE_NO_WINDOW  # pytype: disable=module-attr
         )
-    # try to prevent hangs for programs requiring input
-    kwargs["input"] = ""
+    if not interactive:
+        # try to prevent hangs for programs requiring input
+        kwargs["input"] = ""
     if verbosity < 1:
         # hide command output on stdout
         kwargs['stdout'] = subprocess.DEVNULL
@@ -76,13 +77,15 @@ def run(cmd: Sequence[str], verbosity: int = 0, **kwargs) -> int:
         if kwargs.get("shell"):
             # for shell calls the command must be a string
             cmd = " ".join(cmd)
-    res = subprocess.run(cmd, **kwargs)
+    res = subprocess.run(cmd, check=False, **kwargs)
     return res.returncode
 
 
-def run_checked(cmd: Sequence[str], ret_ok: Sequence[int] = (0,), **kwargs) -> int:
+def run_checked(
+    cmd: Sequence[str], ret_ok: Sequence[int] = (0,), interactive: bool = True, **kwargs
+) -> int:
     """Run command and raise PatoolError on error."""
-    retcode = run(cmd, **kwargs)
+    retcode = run(cmd, interactive=interactive, **kwargs)
     if retcode not in ret_ok:
         msg = f"Command `{cmd}' returned non-zero exit status {retcode}"
         raise PatoolError(msg)
@@ -181,8 +184,8 @@ def find_program(program: str) -> str | None:
 
 def get_nt_7z_dir() -> str:
     """Return 7-Zip directory from registry, or an empty string."""
-    import winreg  # type: ignore
-    import platform
+    import winreg  # noqa: PLC0415
+    import platform  # noqa: PLC0415
 
     python_bits = platform.architecture()[0]
     keyname = r"SOFTWARE\7-Zip"
