@@ -15,7 +15,7 @@
 """Test the 7za program"""
 
 from . import ArchiveTest, Content
-from .. import needs_program
+from .. import needs_program, needs_codec
 
 
 class Test7za(ArchiveTest):
@@ -24,7 +24,7 @@ class Test7za(ArchiveTest):
     program = '7za'
 
     @needs_program(program)
-    def test_p7azip(self):
+    def test_7za(self):
         """Run archive commands with archives that 7za supports."""
         self.archive_commands('t .7z')
         self.archive_commands('t .cb7')
@@ -33,22 +33,27 @@ class Test7za(ArchiveTest):
         self.archive_list('t.txt.gz')
         self.archive_list('t.txt.bz2')
         self.archive_list('t.jar')
-        self.archive_list('t.txt.Z')
         self.archive_list('t.cab')
         self.archive_list('t.rpm')
         self.archive_extract('t.txt.gz', check=Content.Singlefile)
         self.archive_extract('t.txt.bz2', check=Content.Singlefile)
         self.archive_extract('t.jar', check=None)
-        self.archive_extract('t.txt.Z', check=Content.Singlefile)
         self.archive_extract('t.cab')
         self.archive_test('t.txt.gz')
         self.archive_test('t.txt.bz2')
         self.archive_test('t.jar')
-        self.archive_test('t.txt.Z')
         self.archive_test('t.cab')
         self.archive_create('t.txt.gz', check=Content.Singlefile)
         self.archive_create('t.txt.bz2', check=Content.Singlefile)
 
+    @needs_program(program)
+    @needs_codec(program, 'compress')
+    def test_7za_compress(self):
+        """Run archive commands with compress archives."""
+        self.archive_list('t.txt.Z')
+        self.archive_extract('t.txt.Z', check=Content.Singlefile)
+        self.archive_test('t.txt.Z')
+
     @needs_program('file')
     @needs_program(program)
     def test_7za_file(self):
@@ -60,16 +65,22 @@ class Test7za(ArchiveTest):
         self.archive_list('t.txt.gz.foo')
         self.archive_list('t.txt.bz2.foo')
         self.archive_list('t.jar.foo')
-        self.archive_list('t.txt.Z.foo')
         self.archive_list('t.cab.foo')
         self.archive_list('t.rpm.foo')
         self.archive_extract('t.txt.gz.foo', check=None)
         self.archive_extract('t.txt.bz2.foo', check=Content.Singlefile)
         self.archive_extract('t.jar.foo', check=None)
-        self.archive_extract('t.txt.Z.foo', check=Content.Singlefile)
         self.archive_extract('t.cab.foo')
         self.archive_test('t.txt.gz.foo')
         self.archive_test('t.txt.bz2.foo')
         self.archive_test('t.jar.foo')
-        self.archive_test('t.txt.Z.foo')
         self.archive_test('t.cab.foo')
+
+    @needs_program('file')
+    @needs_program(program)
+    @needs_codec(program, 'compress')
+    def test_7za_compress_file(self):
+        """Run archive commands with renamed compress archives."""
+        self.archive_list('t.txt.Z.foo')
+        self.archive_extract('t.txt.Z.foo', check=Content.Singlefile)
+        self.archive_test('t.txt.Z.foo')
