@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2012 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,24 +12,31 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the arj program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestArj (ArchiveTest):
+
+class TestArj(ArchiveTest):
+    """Test class for the arj program"""
 
     program = 'arj'
 
     @needs_program(program)
     def test_arj(self):
+        """Run archive commands with ARJ archive."""
         self.archive_commands(self.filename + '.arj')
 
     @needs_program('file')
     @needs_program(program)
     def test_arj_file(self):
+        """Run archive commands with renamed ARJ archive."""
         self.archive_commands(self.filename + '.arj.foo', skip_create=True)
 
 
 class TestArjPassword(TestArj):
+    """Test class for the arj program with password protected archives"""
 
     password = 'thereisnotry'
     filename = 'p'
