@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2012 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,19 +12,24 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the bsdcpio program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestBsdcpio (ArchiveTest):
+
+class TestBsdcpio(ArchiveTest):
+    """Test class for the bsdcpio program"""
 
     program = 'bsdcpio'
 
     @needs_program(program)
     def test_bsdcpio(self):
+        """Run archive commands with CPIO archive."""
         self.archive_commands('t.cpio')
 
     @needs_program('file')
     @needs_program(program)
     def test_bsdcpio_file(self):
+        """Run archive commands with renamed CPIO archive."""
         self.archive_commands('t.cpio.foo', skip_create=True)
-
