@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,20 +12,24 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the lha program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestLha (ArchiveTest):
+
+class TestLha(ArchiveTest):
+    """Test class for the lha program"""
 
     program = 'lha'
 
     @needs_program(program)
     def _test_lha(self):
-        # XXX currently fails
+        """Run archive commands with LHA archive."""
         self.archive_commands('t.lha')
 
     @needs_program('file')
     @needs_program(program)
     def test_lha_file(self):
+        """Run archive commands with renamed LHA archive."""
         self.archive_commands('t.lha.foo', skip_create=True)
-
