@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2012 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,23 +12,28 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test the xdms program"""
+
 from . import ArchiveTest
 from .. import needs_program
 
-class TestXdms (ArchiveTest):
+
+class TestXdms(ArchiveTest):
+    """Test class for the xdms program"""
 
     program = 'xdms'
 
     @needs_program(program)
     def test_xdms(self):
+        """Test, extract and list a DMS archive."""
         self.archive_extract('t.dms', check=None)
         self.archive_list('t.dms')
         self.archive_test('t.dms')
 
     # xdms(1) cannot handle files without '.dms' extension
-    #@needs_program(program)
-    #def test_xdms_file(self):
+    # @needs_program(program)
+    # def test_xdms_file(self):
+    #    """Test, extract and list a renamed DMS archive."""
     #    self.archive_extract('t.dms.foo')
     #    self.archive_test('t.dms.foo')
     #    self.archive_list('t.dms.foo')
-
