@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-# Copyright (C) 2010-2015 Bastian Kleineidam
+# Copyright (C) 2010-2023 Bastian Kleineidam
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -13,6 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+"""Test patool diff command."""
+
 import unittest
 import os
 from patoolib import cli
@@ -20,11 +21,13 @@ from . import datadir, needs_program
 
 
 class ArchiveDiffTest(unittest.TestCase):
+    """Test class for patool diff command."""
 
     @needs_program('diff')
     @needs_program('tar')
     @needs_program('unzip')
     def test_diff(self):
+        """Run cli function to compare a TAR and ZIP archive."""
         archive1 = os.path.join(datadir, "t.tar")
         archive2 = os.path.join(datadir, "t.zip")
         args = ["-vv", "--non-interactive", "diff", archive1, archive2]
