@@ -17,6 +17,7 @@
 import unittest
 import os
 import patoolib
+import patoolib.mime
 from . import needs_program, datadir
 
 
@@ -131,7 +132,7 @@ class TestMime(unittest.TestCase):
         self.mime_test_file("t.ace.foo", "application/x-ace")
         self.mime_test_file("t.cba", "application/x-ace")
         self.mime_test_file("t.cba.foo", "application/x-ace")
-        # fixme: test errors on windows
+        # test errors on windows
         # self.mime_test_file("t.txt.a", "application/x-archive")
         # self.mime_test_file("t.txt.a.foo", "application/x-archive")
         self.mime_test_file("t.lha", "application/x-lha")
@@ -178,7 +179,7 @@ class TestMime(unittest.TestCase):
         self.mime_test_file("t.zpaq", "application/zpaq")
         self.mime_test_file("t.zpaq.foo", "application/zpaq")
 
-    # fixme: broken tests
+    # file(1) does not recognize .tar.lz files (at least not with --uncompress)
     # @needs_program('file')
     # @needs_program('lzip')
     # def test_mime_file_lzip(self):
@@ -207,21 +208,21 @@ class TestMime(unittest.TestCase):
         self.mime_test_file("t.taz.foo", "application/x-tar", "gzip")
         self.mime_test_file("t.tgz.foo", "application/x-tar", "gzip")
 
-    # fixme: broken tests
+    # broken tests
     # @needs_program('file')
     # @needs_program('xz')
     # def test_mime_file_xzip(self):
     #    """Test mime detection of TAR XZ archives"""
     #    self.mime_test_file("t.tar.xz.foo", "application/x-tar", "xz")
 
-    # fixme: broken tests
+    # file(1) does not recognize .tar.zst files (at least not with --uncompress)
     # @needs_program("file")
     # @needs_program("zstd")
     # def test_mime_file_zstd(self):
     #    """Test mime detection of TAR ZSTD archives"""
     #    self.mime_test_file("t.tar.zst.foo", "application/x-tar", "zstd")
 
-    # fixme: broken tests
+    # file(1) does not recognize .tar.Z files (at least not with --uncompress)
     # @needs_program('file')
     # @needs_program('uncompress')
     # def test_mime_file_compress(self):
